# Security Policy

## Supported Versions

The project supports mostly latest 2 major versions with security updates, although we advise regular
updates (even for major versions), to use the new functions and get bugfixes, which are applied only
to latest versions. Below is a list of which versions (:white_check_mark:) that would get a security update.

| Version | Supported          |
| ------- | ------------------ |
| 7.x.x   | :white_check_mark: |
| 6.0.x   | :x:                |
| 5.0.x   | :white_check_mark: |
| 4.11.x  | :white_check_mark: |
| < 4.11  | :x:                |

## Reporting a Vulnerability

Please report any vulnerabilities as [issues on GitHub](https://github.com/melexis/sphinx-traceability-extension/issues)
Every issue is replied on and checked and you will receive feedback from us there. Make sure you
include ways to replicate it and, if possible, propose a Pull Request with a potential fix.  
